# npc_io

File IO tools for MindScope Neuropixels projects in the cloud.

[![PyPI](https://img.shields.io/pypi/v/npc_io.svg?label=PyPI&color=blue)](https://pypi.org/project/npc_io/)
[![Python version](https://img.shields.io/pypi/pyversions/npc_io)](https://pypi.org/project/npc_io/)

[![Coverage](https://img.shields.io/codecov/c/github/AllenInstitute/npc_io?logo=codecov)](https://app.codecov.io/github/AllenInstitute/npc_io)
[![CI/CD](https://img.shields.io/github/actions/workflow/status/AllenInstitute/npc_io/publish.yml?label=CI/CD&logo=github)](https://github.com/AllenInstitute/npc_io/actions/workflows/publish.yml)
[![GitHub issues](https://img.shields.io/github/issues/AllenInstitute/npc_io?logo=github)](https://github.com/AllenInstitute/npc_io/issues)

# Usage
```bash
conda create -n npc_io python>=3.9
conda activate npc_io
pip install npc_io
```

```python
import npc_io
```

# Development
See instructions in https://github.com/AllenInstitute/npc_io/CONTRIBUTING.md and the original template: https://github.com/AllenInstitute/copier-pdm-npc/blob/main/README.md